globals
[
  reality
  organization-code
  organizational-objectivity
  proportion-of-organization-unknown
  average-individual-objectivity
  average-proportion-of-individual-unknown  
  
  times-of-organization-learning
  times-of-individual-learning-from-organization
  times-of-individual-learning
  organization-learning-efficiency
  objectivity-of-biased-beliefs-in-best-practice
  number-of-individuals-in-best-practice
]

breed [individuals individual]

individuals-own
[
  beliefs
  bias
  individual-objectivity
  proportion-of-individual-unknown
  individual-objectivity-of-biased-beliefs
]

to setup
  ca
  random-seed ran-seed
  set-default-shape individuals "circle"
  create-individuals organization-size
  [ 
    set size 0.3
  ]
  
  ;;;locate individuals in a circle, and make each individual link with the left 2 and the right 2 neighbors
    let n 0
    while [n < organization-size]
    [
      ask individual n 
      [create-link-with individual ((n + 1) mod organization-size)
        create-link-with individual ((n + 2) mod organization-size)]
      set n n + 1
    ]

  layout-circle (sort individuals) max-pxcor - 1
  
  initialize
  set organizational-objectivity -1
  reset-ticks
end

to initialize
  set reality (initialize-list [1 -1])
  set organization-code (initialize-list [0])
  ask individuals
  [  
    initialize-self
  ] 
end

to initialize-self  
    set beliefs (initialize-list [1 -1 0])
    set bias []
    ;;;initialize the bias vector
    repeat task-complexity
    [
      ifelse random 100 < degree-of-individual-bias
      [set bias lput 1 bias]
      [set bias lput 0 bias]
    ]
    let temp-knowledge get-individual-objectivity beliefs
    set individual-objectivity item 0 temp-knowledge
    set proportion-of-individual-unknown item 1 temp-knowledge
    
    ;;;caculate the initial objectivity of biased beliefs
    let i 0
    repeat task-complexity
    [
      if item i bias = 1
      [
        if item i beliefs != 0
        [
          ifelse item i beliefs = item i reality
          [set individual-objectivity-of-biased-beliefs individual-objectivity-of-biased-beliefs + 1]
          [set individual-objectivity-of-biased-beliefs individual-objectivity-of-biased-beliefs - 1]
        ]        
      ]
      set i i + 1
    ]
    if degree-of-individual-bias != 0
    [set individual-objectivity-of-biased-beliefs individual-objectivity-of-biased-beliefs * 100 / (task-complexity * degree-of-individual-bias)]
end

to-report initialize-list [num-set]
  let variable-list []
  repeat task-complexity
  [
    set variable-list lput (one-of num-set) variable-list
  ]    
  report variable-list
end


to-report get-individual-objectivity [variable-beliefs]
  let match 0
  let variable-unknown 0
  (foreach variable-beliefs reality
  [
    ifelse ?1 = 0
    [set variable-unknown variable-unknown + 1]
    [
      if ?1 = ?2
      [set match match + 1]
    ]
  ])
  report sentence ((2 * match - task-complexity + variable-unknown) / task-complexity) (variable-unknown / task-complexity)
end

;;;;;;;;;;;;;;go;;;;;;;;;;;;;;;;;;;
to go
  set times-of-organization-learning 0
  set times-of-individual-learning-from-organization 0
  set times-of-individual-learning 0
  organization-learns-from-individuals
  individuals-learn-from-organization
  individuals-learn-from-each-other
  environment-change
  turnover
  set average-individual-objectivity mean [individual-objectivity] of individuals
  set average-proportion-of-individual-unknown mean [proportion-of-individual-unknown] of individuals
  tick  
end

to organization-learns-from-individuals
  let teachers individuals with [individual-objectivity > organizational-objectivity]
  if any? teachers
  [ 
    set organization-learning-efficiency 0
    set times-of-organization-learning times-of-organization-learning + 1
    set number-of-individuals-in-best-practice count teachers
    set objectivity-of-biased-beliefs-in-best-practice sum [individual-objectivity-of-biased-beliefs] of teachers / number-of-individuals-in-best-practice

    let i 0
    while [i < task-complexity]
    [
      let match-dismatch 0
      foreach sort teachers
      [
        if [item i beliefs] of ? != 0
        [
          ifelse [item i beliefs] of ? = 1
          [set match-dismatch match-dismatch + 1]
          [set match-dismatch match-dismatch - 1]
        ]        
      ]
      if random 100 < probability-organization-learning-from-individuals
      [
        let temp item i reality
        if match-dismatch > 0
        [
          set organization-code replace-item i organization-code 1
          ifelse temp = 1
          [set organization-learning-efficiency organization-learning-efficiency + 1]
          [set organization-learning-efficiency organization-learning-efficiency - 1]
        ]
        if match-dismatch < 0
        [
          set organization-code replace-item i organization-code -1
          ifelse temp = -1
          [set organization-learning-efficiency organization-learning-efficiency + 1]
          [set organization-learning-efficiency organization-learning-efficiency - 1]
        ]
        if match-dismatch = 0
        [
          set organization-code replace-item i organization-code 0
        ]        
      ]
      set i i + 1        
    ]
    set organization-learning-efficiency organization-learning-efficiency / task-complexity
  ]   
    let temp-objectivity (get-individual-objectivity organization-code)
    set organizational-objectivity item 0 temp-objectivity
    set proportion-of-organization-unknown item 1 temp-objectivity
end

to individuals-learn-from-organization
  ask individuals
  [
    set beliefs learned-beliefs-from organization-code probability-individual-learning-from-organization
    let temp-objectivity get-individual-objectivity beliefs
    set individual-objectivity item 0 temp-objectivity
    set proportion-of-individual-unknown item 1 temp-objectivity
  ]
end

to individuals-learn-from-each-other
  ask individuals 
  [ 
    let teacher max-one-of link-neighbors [individual-objectivity]
    ifelse [individual-objectivity] of teacher > individual-objectivity
    [      
      set times-of-individual-learning times-of-individual-learning + 1
      set beliefs learned-beliefs-from [beliefs] of teacher probability-interpersonal-learning
      let temp-objectivity get-individual-objectivity beliefs
      set individual-objectivity item 0 temp-objectivity
      set proportion-of-individual-unknown item 1 temp-objectivity
    ]
    [
      set teacher max-one-of (n-of 4 individuals) [individual-objectivity]
      if [individual-objectivity] of teacher > individual-objectivity
      [ 
        set times-of-individual-learning times-of-individual-learning + 1     
        set beliefs learned-beliefs-from [beliefs] of teacher probability-interpersonal-learning
        let temp-objectivity get-individual-objectivity beliefs
        set individual-objectivity item 0 temp-objectivity
        set proportion-of-individual-unknown item 1 temp-objectivity
      ]
    ]  
  ]
end

to-report learned-beliefs-from [whose-knowledge speed]
  let temp-beliefs beliefs
  let i 0
  repeat task-complexity
  [
    if (item i bias = 0) and (item i whose-knowledge != 0) and random 100 < speed
    [
      set temp-beliefs replace-item i temp-beliefs (item i whose-knowledge)
    ]
    set i i + 1
  ]
  report temp-beliefs  
end




to environment-change
    let i 0
    repeat task-complexity
    [        
      if random 100 < environmental-turbulence
      [
        let temp 0 - item i reality 
        set reality replace-item i reality temp
      ]
      set i i + 1
    ]
    let temp-code (get-individual-objectivity organization-code)
    set organizational-objectivity item 0 temp-code
    set proportion-of-organization-unknown item 1 temp-code
    ask individuals 
    [
      let temp-knowledge get-individual-objectivity beliefs
      set individual-objectivity item 0 temp-knowledge
      set proportion-of-individual-unknown item 1 temp-knowledge
    ] 
  
end

to turnover
  ask individuals
  [
    if random 100 < ratio-turnover
    [
      initialize-self
    ]
  ]  
end
@#$#@#$#@
GRAPHICS-WINDOW
868
25
1245
423
10
10
17.5
1
10
1
1
1
0
0
0
1
-10
10
-10
10
0
0
1
ticks
30.0

BUTTON
6
10
72
43
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
73
10
136
43
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
142
10
214
43
go once
go
NIL
1
T
OBSERVER
NIL
G
NIL
NIL
1

SLIDER
7
46
232
79
ran-seed
ran-seed
0
100
5
1
1
NIL
HORIZONTAL

SLIDER
7
79
232
112
task-complexity
task-complexity
1
500
30
1
1
NIL
HORIZONTAL

SLIDER
6
113
231
146
degree-of-individual-bias
degree-of-individual-bias
0
99
30
5
1
NIL
HORIZONTAL

SLIDER
4
186
231
219
probability-organization-learning-from-individuals
probability-organization-learning-from-individuals
0
100
50
1
1
NIL
HORIZONTAL

SLIDER
4
291
227
324
environmental-turbulence
environmental-turbulence
0
50
0
1
1
NIL
HORIZONTAL

SLIDER
3
226
228
259
probability-interpersonal-learning
probability-interpersonal-learning
0
100
50
1
1
NIL
HORIZONTAL

SLIDER
4
326
227
359
ratio-turnover
ratio-turnover
0
50
0
1
1
NIL
HORIZONTAL

PLOT
257
10
657
156
organization
NIL
NIL
0.0
100.0
-1.0
1.0
true
true
"" ""
PENS
"OO" 1.0 0 -2674135 true "" "plot organizational-objectivity"
"OU" 1.0 0 -13840069 true "" "plot proportion-of-organization-unknown"
"0" 1.0 0 -14737633 true "" "plot 0"
"MAX-Individual" 1.0 0 -7500403 true "" "plot max [individual-objectivity] of turtles"

PLOT
257
158
600
304
Individual
NIL
NIL
0.0
100.0
-1.0
1.0
true
true
"" ""
PENS
"AIO" 1.0 0 -2674135 true "" "plot average-individual-objectivity"
"IU" 1.0 0 -13840069 true "" "plot average-proportion-of-individual-unknown"
"0" 1.0 0 -14737633 true "" "plot 0"

SLIDER
4
260
230
293
probability-individual-learning-from-organization
probability-individual-learning-from-organization
0
100
50
1
1
NIL
HORIZONTAL

SLIDER
5
148
230
181
organization-size
organization-size
50
1000
250
50
1
NIL
HORIZONTAL

PLOT
258
308
471
428
organization learning times
NIL
NIL
0.0
10.0
0.0
2.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot times-of-organization-learning"

PLOT
482
309
697
429
individiual learning times
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot times-of-individual-learning"

PLOT
662
10
896
156
organization-learning efficiency
NIL
NIL
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 2 -16777216 true "" "plot organization-learning-efficiency"
"pen-1" 1.0 0 -13840069 true "" "plot 0"

PLOT
603
157
899
304
objectivity of biased beliefs in best practice
NIL
NIL
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot objectivity-of-biased-beliefs-in-best-practice"
"0" 1.0 0 -10899396 true "" "plot 0"
"mean" 1.0 0 -7500403 true "" "plot mean [individual-objectivity-of-biased-beliefs] of turtles"

@#$#@#$#@
## WHAT IS IT?



## HOW IT WORKS

This section could explain what rules the agents use to create the overall behavior of the model.

## HOW TO USE IT

This section could explain how to use the model, including a description of each of the items in the interface tab.

## THINGS TO NOTICE

This section could give some ideas of things for the user to notice while running the model.

## THINGS TO TRY

This section could give some ideas of things for the user to try to do (move sliders, switches, etc.) with the model.

## EXTENDING THE MODEL

This section could give some ideas of things to add or change in the procedures tab to make the model more complicated, detailed, accurate, etc.

## NETLOGO FEATURES

This section could point out any especially interesting or unusual features of NetLogo that the model makes use of, particularly in the Procedures tab.  It might also point out places where workarounds were needed because of missing features.

## RELATED MODELS

This section could give the names of models in the NetLogo Models Library or elsewhere which are of related interest.

## CREDITS AND REFERENCES

This section could contain a reference to the model's URL on the web if it has one, as well as any other necessary credits or references.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="200"/>
    <metric>organizational-objectivity</metric>
    <metric>average-individual-objectivity</metric>
    <metric>organization-learning-efficiency</metric>
    <metric>objectivity-of-biased-beliefs-in-best-practice</metric>
    <enumeratedValueSet variable="organization-size">
      <value value="50"/>
      <value value="150"/>
      <value value="250"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="probability-interpersonal-learning">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="task-complexity">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="probability-individual-learning-from-organization">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ran-seed">
      <value value="1"/>
      <value value="9"/>
      <value value="3"/>
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="degree-of-individual-bias">
      <value value="0"/>
      <value value="5"/>
      <value value="15"/>
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ratio-turnover">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="probability-organization-learning-from-individuals">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="environmental-turbulence">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 1.0 0.0
0.0 1 1.0 0.0
0.2 0 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
